@@ -53,7 +53,8 @@ The ```agg``` Language Grammar:
     snumber             	:: NUMBER
                         	 | MINUS NUMBER %prec UMINUS
 
-    sev                 	:: sev PLUS numbers
+    sev                 	:: sev UNCONDITIONAL
+                             | sev PLUS numbers
                         	 | sev MINUS numbers
                         	 | numbers TIMES sev
                         	 | ids numbers CV numbers weights
@@ -231,13 +232,13 @@ class UnderwritingLexer(Lexer):
               MIXED, FREQ
               }
     ignore = ' \t,\\:\\(\\)|'
-    literals = {'[', ']'}
+    literals = {'[', ']', '!'}
 
     # per manual, need to list longer tokens before shorter ones
     # NOTE = r'note\{[0-9a-zA-Z,\.\(\)\-=\+!\s]*\}'  # r'[^\}]+'
     NOTE = r'note\{[^\}]*\}'  # r'[^\}]+'
-    BUILTINID = r'(sev|agg|port|meta)\.[a-zA-Z][a-zA-Z0-9_]*'
-    FREQ = r'binomial|poisson|bernoulli|pascal|fixed'
+    BUILTINID = r'(sev|agg|port|meta)\.[a-zA-Z][a-zA-Z0-9_:~]*'
+    FREQ = r'binomial|poisson|bernoulli|pascal|geometric|fixed'
     # do not allow _ in line names, use ~ or . or : instead: why: because p_ is used and _ is special
     # on honor system...really need two types of ID, it is OK in a portfolio name
     ID = r'[a-zA-Z][\.:~_a-zA-Z0-9]*'
@@ -264,6 +265,7 @@ class UnderwritingLexer(Lexer):
     # ID['on'] = SEV
     ID['agg'] = AGG
     ID['port'] = PORT
+    # ID['!'] = UNCONDITIONAL
 
     @_(r'\-?(\d+\.?\d*|\d*\.\d+)([eE](\+|\-)?\d+)?')
     def NUMBER(self, t):
@@ -298,13 +300,10 @@ class UnderwritingParser(Parser):
         if debug:
             def _print(message):
                 print(message)
-
-            self.log = _print
         else:
             def _print(message):
-                logger.info('UnderwritingParser | ' + message)
-
-            self.log = _print
+                logger.debug('UnderwritingParser | ' + message)
+        self.log = _print
 
     def reset(self):
         # TODO Add sev_xs and sev_ps !!
@@ -428,7 +427,7 @@ class UnderwritingParser(Parser):
     @_('FREQ')
     def freq(self, p):
         self.log(f'resolving named frequency distribution {p.FREQ} to freq')
-        if p.FREQ not in ('poisson', 'bernoulli', 'fixed'):
+        if p.FREQ not in ('poisson', 'bernoulli', 'fixed', 'geometric'):
             warnings.warn(f'Illogical choice for FREQ {p.FREQ}, should be poisson, bernoulli or fixed')
         return {'freq_name': p.FREQ}
 
@@ -449,6 +448,13 @@ class UnderwritingParser(Parser):
     #     return { 'freq_name': 'poisson'}
 
     # severity term ============================================
+    @_('sev "!"')
+    def sev(self, p):
+        self.log(f'setting conditional flag on severity to False (this is unusual behaviour, '
+                  'usually want conditional severity)')
+        p.sev['sev_conditional'] = False
+        return p.sev
+
     @_('sev PLUS numbers')
     def sev(self, p):
         self.log(f'resolving sev PLUS numbers to sev {p.numbers}')
@@ -471,7 +477,6 @@ class UnderwritingParser(Parser):
             p.sev['sev_mean'] = UnderwritingParser._check_vectorizable(p.sev.get('sev_mean', 0))
             p.sev['sev_mean'] *= p.numbers
         # only scale scale if there is a scale (otherwise you double count)
-        # TODO OK? sev_scale...
         if 'sev_scale' in p.sev:
             p.sev['sev_scale'] = UnderwritingParser._check_vectorizable(p.sev.get('sev_scale', 0))
             p.sev['sev_scale'] *= p.numbers
@@ -480,7 +485,7 @@ class UnderwritingParser(Parser):
             # but if there is a mean it handles the scaling and setting scale will
             # confuse the distribution maker
             p.sev['sev_scale'] = p.numbers
-        # if there is a location it needs to scale too
+        # if there is a location it needs to scale too --- that's a curious choice!
         if 'sev_loc' in p.sev:
             p.sev['sev_loc'] = UnderwritingParser._check_vectorizable(p.sev['sev_loc'])
             p.sev['sev_loc'] *= p.numbers
@@ -560,7 +565,7 @@ class UnderwritingParser(Parser):
         else:
             return self._safe_lookup(p.builtinids)
 
-    # layer terms, optoinal ===================================
+    # layer terms, optional ===================================
     @_('numbers XS numbers')
     def layers(self, p):
         self.log(f'resolving numbers XS numbers to layers {p[0]} xs {p[2]}')
@@ -713,7 +718,7 @@ class UnderwritingParser(Parser):
 
     @_('builtin_aggregate_dist')
     def builtin_aggregate(self, p):
-        self.log('builtin_aggregate_dist becomese builtin_aggregate')
+        self.log('builtin_aggregate_dist becomes builtin_aggregate')
         return p.builtin_aggregate_dist
 
     @_('BUILTINID')
